<?php
/*
 * Plugin Name:       ETWP day/week/month shortcode content (EasyToolsWP)
 * Description:       Displays messages based on specified time intervals using shortcodes.
 * Version:           1.0.8
 * Requires at least: 6.6
 * Author:            EasyToolsWP.com
 */

// Original Shortcode function to display content based on time intervals
function etwp_campaign_shortcode($atts, $content = null) {
    // Parse shortcode attributes
    $atts = shortcode_atts(array(
        'week' => '',
        'date' => '',
        'day' => '',
        'month' => '',
    ), $atts);

    $current_week = date('W');
    $current_date = date('j');
    $current_day = strtolower(date('l'));
    $current_month = strtolower(date('F'));

    // Check week
    if (!empty($atts['week']) && $atts['week'] != $current_week) {
        return '';
    }

    // Check date
    if (!empty($atts['date'])) {
        $dates = explode(',', $atts['date']);
        if (!in_array($current_date, $dates)) {
            return '';
        }
    }

    // Check day
    if (!empty($atts['day']) && strtolower($atts['day']) != $current_day) {
        return '';
    }

    // Check month
    if (!empty($atts['month']) && strtolower($atts['month']) != $current_month) {
        return '';
    }

    // Remove <br> tags around shortcode content
    $content = preg_replace('/(<br\s*\/?>\s*)+/', '', $content);

    // Return content wrapped in inline span
    return '<span class="etwp-campaign-inline">' . do_shortcode($content) . '</span>';
}

add_shortcode('etwp_campaign', 'etwp_campaign_shortcode');

// Add CSS to make sure the content is displayed inline
function etwp_campaign_enqueue_styles() {
    echo '<style>
        .etwp-campaign-inline {
            display: inline;
        }
    </style>';
}
add_action('wp_head', 'etwp_campaign_enqueue_styles');

// Remove <br> tags automatically added by WordPress
function etwp_campaign_cleanup($content) {
    $content = preg_replace('/<br\s*\/?>/i', '', $content);
    return $content;
}
add_filter('the_content', 'etwp_campaign_cleanup');

// Shortcode to display the example shortcodes as plain text
function show_shortcode_example($atts, $content = null) {
    return '<code>' . esc_html($content) . '</code>';
}
add_shortcode('show_shortcode', 'show_shortcode_example');

// New Dynamic Shortcode function to display dynamic time intervals
function etwp_campaign_dynamic_shortcode($atts) {
    // Parse shortcode attributes
    $atts = shortcode_atts(array(
        'day' => '',
        'month' => '',
        'week' => '',
        'date' => '',
    ), $atts);

    // Ensure functions are not redeclared
    if (!function_exists('get_day_from_offset')) {
        // Function to get day based on relative offset
        function get_day_from_offset($offset) {
            switch ($offset) {
                case 'yesterday':
                    return date('l', strtotime('-1 day'));
                case 'today':
                    return date('l');
                case 'tomorrow':
                    return date('l', strtotime('+1 day'));
                default:
                    // Check if it's an offset like '-2 days' or '+2 days'
                    if (preg_match('/^([-+]?\d+) days?$/', $offset, $matches)) {
                        return date('l', strtotime($offset));
                    } else {
                        return ''; // Invalid offset
                    }
            }
        }
    }

    if (!function_exists('get_month_from_offset')) {
        // Function to get month based on relative offset
        function get_month_from_offset($offset) {
            switch ($offset) {
                case 'last':
                    return date('F', strtotime('last month'));
                case 'this':
                    return date('F');
                case 'next':
                    return date('F', strtotime('next month'));
                default:
                    // Check if it's an offset like '-3 months' or '+3 months'
                    if (preg_match('/^([-+]?\d+) months?$/', $offset, $matches)) {
                        return date('F', strtotime($offset));
                    } else {
                        return ''; // Invalid offset
                    }
            }
        }
    }

    if (!function_exists('get_week_from_offset')) {
        // Function to get week based on relative offset
        function get_week_from_offset($offset) {
            switch ($offset) {
                case 'last':
                    return date('W', strtotime('last week'));
                case 'this':
                    return date('W');
                case 'next':
                    return date('W', strtotime('next week'));
                default:
                    // Check if it's an offset like '-3 weeks' or '+3 weeks'
                    if (preg_match('/^([-+]?\d+) weeks?$/', $offset, $matches)) {
                        return date('W', strtotime($offset));
                    } else {
                        return ''; // Invalid offset
                    }
            }
        }
    }

    if (!function_exists('get_date_from_offset')) {
        // Function to get date based on relative offset
        function get_date_from_offset($offset) {
            switch ($offset) {
                case 'yesterday':
                    return date('j', strtotime('-1 day'));
                case 'today':
                    return date('j');
                case 'tomorrow':
                    return date('j', strtotime('+1 day'));
                default:
                    // Check if it's an offset like '-2 days' or '+2 days'
                    if (preg_match('/^([-+]?\d+) days?$/', $offset, $matches)) {
                        return date('j', strtotime($offset));
                    } else {
                        return ''; // Invalid offset
                    }
            }
        }
    }

    // Determine which attribute is provided and return corresponding value
    if (!empty($atts['day'])) {
        return get_day_from_offset(strtolower($atts['day']));
    } elseif (!empty($atts['month'])) {
        return get_month_from_offset(strtolower($atts['month']));
    } elseif (!empty($atts['week'])) {
        return get_week_from_offset(strtolower($atts['week']));
    } elseif (!empty($atts['date'])) {
        return get_date_from_offset(strtolower($atts['date']));
    }

    return ''; // Default return empty string if no valid attribute found
}

add_shortcode('etwp_campaign_dynamic', 'etwp_campaign_dynamic_shortcode');

?>
